@@ -21,10 +21,11 @@ This is the TaskEditor
 
 It's the window you see when you double-click on a Task
 The main text widget is a home-made TextView called TaskView (see taskview.py)
-The rest is the logic of the widget : date changing widgets, buttons, ...
+The rest is the logic of the widget: date changing widgets, buttons, ...
 """
 import time
 
+import pango
 import gtk
 
 from GTG                     import _, ngettext
@@ -33,24 +34,18 @@ from GTG.gtk.editor.taskview import TaskView
 from GTG.core.plugins.engine import PluginEngine
 from GTG.core.plugins.api    import PluginAPI
 from GTG.core.task           import Task
-from GTG.tools               import dates
+from GTG.tools.dates         import Date
 from GTG.gtk.editor.calendar import GTGCalendar
 
-
-date_separator = "-"
-
-
-
 class TaskEditor:
 
-
     def __init__(self, 
                  requester, 
                  vmanager, 
                  task, 
                  taskconfig = None,
                  thisisnew = False,
-                 clipboard = None) :
+                 clipboard = None):
         '''
         req is the requester
         vmanager is the view manager
@@ -58,6 +53,7 @@ class TaskEditor:
         thisisnew is True when a new task is created and opened
         '''
         self.req = requester
+        self.browser_config = self.req.get_config('browser')
         self.vmanager = vmanager
         self.config = taskconfig
         self.time = None
@@ -74,25 +70,25 @@ class TaskEditor:
         self.inserttag_button.set_tooltip_text(GnomeConfig.TAG_TOOLTIP)
         #Create our dictionary and connect it
         dic = {
-                "mark_as_done_clicked"      : self.change_status,
-                "on_dismiss"                : self.dismiss,
-                "delete_clicked"            : self.delete_task,
-                "on_duedate_pressed"        : (self.on_date_pressed,
+                "mark_as_done_clicked": self.change_status,
+                "on_dismiss": self.dismiss,
+                "delete_clicked": self.delete_task,
+                "on_duedate_pressed": (self.on_date_pressed,
                                                GTGCalendar.DATE_KIND_DUE),
-                "on_startdate_pressed"      : (self.on_date_pressed,
+                "on_startdate_pressed": (self.on_date_pressed,
                                                GTGCalendar.DATE_KIND_START),
-                "on_closeddate_pressed"     : (self.on_date_pressed,
+                "on_closeddate_pressed": (self.on_date_pressed,
                                                GTGCalendar.DATE_KIND_CLOSED),
-                "close_clicked"             : self.close,
-                "duedate_changed"           : (self.date_changed,
+                "close_clicked": self.close,
+                "duedate_changed": (self.date_changed,
                                                GTGCalendar.DATE_KIND_DUE),
-                "startingdate_changed"      : (self.date_changed,
+                "startingdate_changed": (self.date_changed,
                                                GTGCalendar.DATE_KIND_START),
-                "closeddate_changed"        : (self.date_changed,
+                "closeddate_changed": (self.date_changed,
                                                GTGCalendar.DATE_KIND_CLOSED),
-                "on_insert_subtask_clicked" : self.insert_subtask,
-                "on_inserttag_clicked"      : self.inserttag_clicked,
-                "on_move"                   : self.on_move,
+                "on_insert_subtask_clicked": self.insert_subtask,
+                "on_inserttag_clicked": self.inserttag_clicked,
+                "on_move": self.on_move,
         }
         self.builder.connect_signals(dic)
         self.window         = self.builder.get_object("TaskEditor")
@@ -101,13 +97,16 @@ class TaskEditor:
         textview = self.builder.get_object("textview")
         scrolled = self.builder.get_object("scrolledtask")
         scrolled.remove(textview)
-        self.textview   = TaskView(self.req,self.clipboard)
+        self.textview   = TaskView(self.req, self.clipboard)
         self.textview.show()
         self.textview.set_subtask_callback(self.new_subtask)
         self.textview.open_task_callback(self.vmanager.open_task)
         self.textview.set_left_margin(7)
         self.textview.set_right_margin(5)
         scrolled.add(self.textview)
+        conf_font_value = self.browser_config.get("font_name")
+        if conf_font_value!= "":
+            self.textview.modify_font(pango.FontDescription(conf_font_value)) 
         #Voila! it's done
         self.calendar       = GTGCalendar(self.builder)
         self.duedate_widget = self.builder.get_object("duedate_entry")
@@ -132,22 +131,22 @@ class TaskEditor:
         #the first line is the title
         self.textview.set_text("%s\n"%title)
         #we insert the rest of the task
-        if texte :
+        if texte:
             self.textview.insert("%s"%texte)
-        else :
+        else:
             #If not text, we insert tags
-            if tags :
-                for t in tags :
+            if tags:
+                for t in tags:
                     self.textview.insert_text("%s, "%t.get_name())
                 self.textview.insert_text("\n")
             #If we don't have text, we still need to insert subtasks if any
             subtasks = task.get_children()
-            if subtasks :
+            if subtasks:
                 self.textview.insert_subtasks(subtasks)
         #We select the title if it's a new task
-        if thisisnew :
+        if thisisnew:
             self.textview.select_title()
-        else :
+        else:
             self.task.set_to_keep()
         self.textview.modified(full=True)
         self.window.connect("destroy", self.destruction)
@@ -165,7 +164,7 @@ class TaskEditor:
         self.textview.grab_focus()
 
         #restoring size and position, spatial tasks
-        if self.config :
+        if self.config:
             tid = self.task.get_id()
             if tid in self.config:
                 if "position" in self.config[tid]:
@@ -174,21 +173,14 @@ class TaskEditor:
                     #print "restoring position %s %s" %(pos[0],pos[1])
                 if "size" in self.config[tid]:
                     size = self.config[tid]["size"]
-                    #print "size %s - %s" %(str(size[0]),str(size[1]))
+                    #print "size %s - %s" %(str(size[0]), str(size[1]))
                     #this eval(str()) is a ugly (!) hack to accept both int and str
                     #FIXME: Fix this!
                     self.window.resize(eval(str(size[0])),eval(str(size[1])))
 
         self.textview.set_editable(True)
-        #Connection for the update
-        self.req.connect('task-modified',self.task_modified)
         self.window.show()
 
-
-    #FIXME: avoid to update to many time when we modify from the editor itself
-    def task_modified(self,sender,tid):
-        self.refresh_editor(refreshtext=True)
-
     # Define accelerator-keys for this dialog
     # TODO: undo/redo
     def init_accelerators(self):
@@ -233,10 +225,10 @@ class TaskEditor:
             return
         to_save = False
         #title of the window 
-        if title :
+        if title:
             self.window.set_title(title)
             to_save = True
-        else :
+        else:
             self.window.set_title(self.task.get_title())
 
         status = self.task.get_status() 
@@ -276,18 +268,34 @@ class TaskEditor:
             self.builder.get_object("label2").show() 
             self.builder.get_object("hbox1").show()
 
+        #refreshing the start date field
+        startdate = self.task.get_start_date()
+        try:
+            prevdate = Date.parse(self.startdate_widget.get_text())
+            update_date = startdate != prevdate
+        except ValueError:
+            update_date = True
+
+        if update_date:
+            self.startdate_widget.set_text(str(startdate)) 
+
         #refreshing the due date field
         duedate = self.task.get_due_date()
-        prevdate = dates.strtodate(self.duedate_widget.get_text())
-        if duedate != prevdate or type(duedate) is not type(prevdate):
-            zedate = str(duedate).replace("-", date_separator)
-            self.duedate_widget.set_text(zedate)
+        try:
+            prevdate = Date.parse(self.duedate_widget.get_text())
+            update_date = duedate != prevdate
+        except ValueError:
+            update_date = True
+
+        if update_date:
+            self.duedate_widget.set_text(str(duedate))
+
         # refreshing the closed date field
         closeddate = self.task.get_closed_date()
-        prevcldate = dates.strtodate(self.closeddate_widget.get_text())
-        if closeddate != prevcldate or type(closeddate) is not type(prevcldate):
-            zecldate = str(closeddate).replace("-", date_separator)
-            self.closeddate_widget.set_text(zecldate)
+        prevcldate = Date.parse(self.closeddate_widget.get_text())
+        if closeddate != prevcldate:
+            self.closeddate_widget.set_text(str(closeddate))
+
         #refreshing the day left label
         #If the task is marked as done, we display the delay between the 
         #due date and the actual closing date. If the task isn't marked 
@@ -304,8 +312,9 @@ class TaskEditor:
                 abs_delay = abs(delay)
                 txt = ngettext("Completed %(days)d day early", "Completed %(days)d days early", abs_delay) % {'days': abs_delay}
         else:
-            result = self.task.get_days_left()
-            if result is None:
+            due_date = self.task.get_due_date()
+            result = due_date.days_left()
+            if due_date.is_fuzzy():
                 txt = ""
             elif result > 0:
                 txt = ngettext("Due tomorrow!", "%(days)d days left", result) % {'days': result}
@@ -318,11 +327,6 @@ class TaskEditor:
         color = str(window_style.text[gtk.STATE_INSENSITIVE])
         self.dayleft_label.set_markup("<span color='"+color+"'>"+txt+"</span>")
 
-        startdate = self.task.get_start_date()
-        prevdate = dates.strtodate(self.startdate_widget.get_text())
-        if startdate != prevdate or type(startdate) is not type(prevdate):
-            zedate = str(startdate).replace("-",date_separator)
-            self.startdate_widget.set_text(zedate) 
         #Refreshing the tag list in the insert tag button
         taglist = self.req.get_used_tags()
         menu = gtk.Menu()
@@ -336,7 +340,7 @@ class TaskEditor:
                 mi.connect("activate", self.inserttag, tagname)
                 mi.show()
                 menu.append(mi)
-        if tag_count > 0 :
+        if tag_count > 0:
             self.inserttag_button.set_menu(menu)
 
         if refreshtext:
@@ -346,51 +350,39 @@ class TaskEditor:
 
     def date_changed(self,widget,data):
         text = widget.get_text()
-        validdate = False
-        if not text :
-            validdate = True
-            datetoset = dates.no_date
-        else :
-            datetoset = dates.strtodate(text)
-            if datetoset :
-                validdate = True
+        valid = True
+        if not text:
+            datetoset = Date.no_date()
+        else:
+            try:
+                datetoset = Date.parse(text)
+            except ValueError:
+                valid = False
 
-        if validdate :
+        if valid:
             #If the date is valid, we write with default color in the widget
             # "none" will set the default color.
             widget.modify_text(gtk.STATE_NORMAL, None)
             widget.modify_base(gtk.STATE_NORMAL, None)
-            if data == "start" :
+
+            if data == "start":
                 self.task.set_start_date(datetoset)
-            elif data == "due" :
+            elif data == "due":
                 self.task.set_due_date(datetoset)
-            elif data == "closed" :
+            elif data == "closed":
                 self.task.set_closed_date(datetoset)
-            #Set the due date to be equal to the start date
-            # when it happens that the start date is later than the due date
-            start_date = self.task.get_start_date()
-            due_date = self.task.get_due_date()
-            if start_date and (start_date > due_date):
-                self.task.set_due_date(self.task.get_start_date())
-        else :
+        else:
             #We should write in red in the entry if the date is not valid
             widget.modify_text(gtk.STATE_NORMAL, gtk.gdk.color_parse("#F00"))
             widget.modify_base(gtk.STATE_NORMAL, gtk.gdk.color_parse("#F88"))
 
-
-
     def on_date_pressed(self, widget, date_kind):
         """Called when a date-changing button is clicked."""
         if date_kind == GTGCalendar.DATE_KIND_DUE:
-            date = self.task.get_due_date()
-
-            # is due_date < start_date ?
-            # no_date need special care because we want to no_date < anything
-            start_date = self.task.get_start_date()
-            due_before_start = start_date != dates.no_date and start_date > date
-
-            if not date or due_before_start:
+            if not self.task.get_due_date():
                 date = self.task.get_start_date()
+            else:
+                date = self.task.get_due_date()
         elif date_kind == GTGCalendar.DATE_KIND_START:
             date = self.task.get_start_date()
         elif date_kind == GTGCalendar.DATE_KIND_CLOSED:
@@ -402,7 +394,6 @@ class TaskEditor:
         self.calendar.show_at_position(x + rect.x + rect.width,
                                        y + rect.y)
 
-
     def on_date_changed(self, calendar):
         date, date_kind = calendar.get_selected_date()
         if date_kind == GTGCalendar.DATE_KIND_DUE:
@@ -413,25 +404,41 @@ class TaskEditor:
             self.task.set_closed_date(date)
         self.refresh_editor()
 
-    def dismiss(self,widget) : #pylint: disable-msg=W0613
+    def close_all_subtasks(self):
+        all_subtasks = []
+
+        def trace_subtasks(root):
+            for i in root.get_subtasks():
+                if i not in all_subtasks:
+                    all_subtasks.append(i)
+                    trace_subtasks(i)
+
+        trace_subtasks(self.task)
+
+        for task in all_subtasks:
+            self.vmanager.close_task(task.get_id())
+
+    def dismiss(self,widget): #pylint: disable-msg=W0613
         stat = self.task.get_status()
         if stat == "Dismiss":
             self.task.set_status("Active")
             self.refresh_editor()
         else:
             self.task.set_status("Dismiss")
+            self.close_all_subtasks()
             self.close(None)
 
-    def change_status(self,widget) : #pylint: disable-msg=W0613
+    def change_status(self,widget): #pylint: disable-msg=W0613
         stat = self.task.get_status()
         if stat == "Done":
             self.task.set_status("Active")
             self.refresh_editor()
         else:
             self.task.set_status("Done")
+            self.close_all_subtasks()
             self.close(None)
 
-    def delete_task(self, widget) :
+    def delete_task(self, widget):
         #this triggers the closing of the window in the view manager
         if self.task.is_new():
 #            self.req.delete_task(self.task.get_id())
@@ -440,7 +447,7 @@ class TaskEditor:
             self.vmanager.ask_delete_tasks([self.task.get_id()])
 
     #Take the title as argument and return the subtask ID
-    def new_subtask(self,title=None,tid=None) :
+    def new_subtask(self,title=None,tid=None):
         if tid:
             self.task.add_child(tid)
         elif title:
@@ -455,23 +462,23 @@ class TaskEditor:
         task_id = task.get_id()
         self.vmanager.open_task(task_id)
 
-    def insert_subtask(self,widget) : #pylint: disable-msg=W0613
+    def insert_subtask(self,widget): #pylint: disable-msg=W0613
         self.textview.insert_newtask()
         self.textview.grab_focus()
 
-    def inserttag_clicked(self,widget) : #pylint: disable-msg=W0613
+    def inserttag_clicked(self,widget): #pylint: disable-msg=W0613
         itera = self.textview.get_insert()
-        if itera.starts_line() :
+        if itera.starts_line():
             self.textview.insert_text("@",itera)
-        else :
+        else:
             self.textview.insert_text(" @",itera)
         self.textview.grab_focus()
 
-    def inserttag(self,widget,tag) : #pylint: disable-msg=W0613
+    def inserttag(self,widget,tag): #pylint: disable-msg=W0613
         self.textview.insert_tags([tag])
         self.textview.grab_focus()
 
-    def save(self) :
+    def save(self):
         self.task.set_title(self.textview.get_title())
         self.task.set_text(self.textview.get_text()) 
         self.task.sync()
@@ -480,7 +487,7 @@ class TaskEditor:
         self.time = time.time()
     #light_save save the task without refreshing every 30seconds
     #We will reduce the time when the get_text will be in another thread
-    def light_save(self) :
+    def light_save(self):
         #if self.time is none, we never called any save
         if self.time:
             diff = time.time() - self.time
@@ -511,7 +518,7 @@ class TaskEditor:
         #saving the position
         if self.config != None:
             tid = self.task.get_id()
-            if not tid in self.config :
+            if not tid in self.config:
                 self.config[tid] = dict()
             #print "saving task position %s" %str(self.get_position())
             self.config[tid]["position"] = self.get_position()
