@@ -18,4 +18,5 @@ from GTG.plugins.tomboy.tomboy import pluginTomboy
 
 
 #suppress pyflakes warning (given by make lint)
-if False == True: pluginTomboy()
+if False == True:
+    pluginTomboy()
